@@ -8,7 +8,7 @@ local atk = {}
 
 mem.lanedistance = mem.lanedistance or mem.enemyclose or 3e3
 --mem.atk_pref_func = nil
-mem.atk_pref_range = 5e3
+mem.atk_pref_range = 5e3 -- Range to prefer to attack from
 
 --[[
 --Attempts to maintain a constant distance from nearby things
@@ -128,26 +128,18 @@ function atk.heuristic_big_game_think( target, _si )
       return
    end
 
-   local enemy = atk.preferred_enemy( atk.prefer_capship )
-
+   -- Don't switch targets if close to current one
    local dist = ai.dist(target)
    local range = ai.getweaprange(3, 0)
-   -- Get new target if it's closer
-   -- prioritize targets within the size limit
-   if enemy ~= target and enemy ~= nil then
-      -- Shouldn't switch targets if close
-      if dist > range * mem.atk_changetarget then
-         ai.pushtask("attack", enemy )
-      end
+   if dist < range * mem.atk_changetarget then
       return
    end
 
-   local nearest_enemy = ai.getenemy()
-   if nearest_enemy ~= target and nearest_enemy ~= nil then
-      -- Shouldn't switch targets if close
-      if dist > range * mem.atk_changetarget then
-         ai.pushtask("attack", nearest_enemy )
-      end
+   -- Prioritize preferred target
+   local enemy = atk.preferred_enemy( atk.prefer_capship )
+   if enemy ~= target and enemy ~= nil then
+      ai.pushtask("attack", enemy )
+      return
    end
 end
 
@@ -293,7 +285,7 @@ local function ___atk_g_ranged_dogfight( target, dist )
       end
    else
       -- Test if we should zz
-      if ai.pilot():stats().mass < 400 and atk.decide_zz( target, dist ) then
+      if ai.pilot():mass() < 400 and atk.decide_zz( target, dist ) then
          ai.pushsubtask("_attack_zigzag", target)
       end
    end
@@ -378,7 +370,7 @@ local function ___atk_g_ranged_strafe( target, dist )
    --From now, if ship doesn't manage to stabilize within a few seconds, shoot anyway
    if dist < 1.5*range and not mem.inzone then
       mem.inzone = true
-      ai.settimer(1, mod/p:stats().speed*0.7 )
+      ai.settimer(1, mod/p:speed()*0.7 )
    end
 end
 local function ___atk_g_ranged_kite( target, dist )
@@ -392,7 +384,7 @@ local function ___atk_g_ranged_kite( target, dist )
    local selfpos = p:pos()
    local _unused, targetdir = (selfpos-targetpos):polar()
    local velmod, veldir = p:vel():polar()
-   if velmod < 0.8*p:stats().speed or math.abs(targetdir-veldir) > math.rad(30) then
+   if velmod < 0.8*p:speed() or math.abs(targetdir-veldir) > math.rad(30) then
       local dir = ai.face( target, true )
       if math.abs(math.pi-dir) < math.rad(30) then
          ai.accel()
@@ -423,7 +415,7 @@ function atk.ranged( target, dist )
 
    -- Pilot thinks dogfight is the best
    if ai.relhp(target)*ai.reldps(target) >= 0.25
-         or ai.getweapspeed(4) < target:stats().speed_max*1.2
+         or ai.getweapspeed(4) < target:speedMax()*1.2
          or range < ai.getweaprange(1)*1.5 then
       ___atk_g_ranged_dogfight( target, dist )
    elseif target:target()==ai.pilot() and dist < range and ai.hasprojectile() then
@@ -500,19 +492,25 @@ end
 --[[
 Tries to find a preferred enemy.
 --]]
-function atk.preferred_enemy( pref_func )
+function atk.preferred_enemy( pref_func, checkvuln )
    pref_func = mem.atk_pref_func or pref_func or atk.prefer_similar
    local p = ai.pilot()
    local r = math.pow( mem.lanedistance, 2 )
-   local maxrange = mem.atk_pref_range
    local targets = {}
-   for k,h in ipairs( p:getEnemies( maxrange, nil, false, false, true ) ) do
+   for k,h in ipairs( p:getEnemies( mem.enemyclose, nil, false, false, true ) ) do
       local w = h:memory().vulnerability or 0
       if w < math.huge then -- math.huge can be used to make the AI try not to target
-         local v, F, H = careful.checkVulnerable( p, h, mem.vulnattack, r )
-         if not v then
+         local v, F, H
+         if not checkvuln then
+            v = true
             F = 1
             H = 1
+         else
+            v, F, H = careful.checkVulnerable( p, h, mem.vulnattack, r )
+            if not v then
+               F = 1
+               H = 1
+            end
          end
          -- Insert some randomness for less consistency
          w = w + (0.9+0.2*rnd.rnd())*pref_func( p, h, v, F, H ) -- Compute pref function
