@@ -13,6 +13,8 @@
 require "proximity"
 local fmt = require "format"
 local formation = require "formation"
+local vn = require "vn"
+local ccomm = require "common.comm"
 
 -- Non-persistent state
 local source_system, source_planet, battleEnded, side
@@ -22,11 +24,11 @@ local reward
 local finvader, flocal
 
 function create ()
-   -- Doesn't pilot.clear so inclusive claim
-   if not evt.claim( system.cur(), false, true ) then
-      evt.finish( false )
-   end
    source_system = system.cur()
+   hook.safe( "setup" ) -- delay the jumpin hook one frame
+end
+
+function setup ()
    jumphook = hook.jumpin("begin")
    hook.land("leave")
 end
@@ -40,7 +42,8 @@ function begin ()
       if thissystem == s then areAdj = true end
    end
 
-   if not evt.claim(thissystem) or not areAdj then
+   -- Doesn't pilot.clear so inclusive claim
+   if not evt.claim(thissystem, true) or not areAdj then
       evt.finish(false)
    end
 
@@ -87,13 +90,21 @@ function merchant ()
 end
 
 function hailme()
-    trader:hailPlayer()
-    hailhook = hook.pilot(trader, "hail", "hail")
+   trader:hailPlayer()
+   hailhook = hook.pilot(trader, "hail", "hail")
 end
 
-function hail()
-   hook.rm(hailhook)
-   tk.msg(_("A battle is about to begin"), fmt.f(_([["Hey, you," the captain of the ship says. "You seem not to know what is going to happen here: a mighty warlord from {sys} is going to attack {pnt}. You shouldn't stay there, unless you are a mercenary. Do you know how it works? If you attack a warlord's ship, and he loses the battle, the other warlord will reward you. But if he wins, you will be hunted down."]]), {sys=source_system, pnt=source_planet}))
+function hail ()
+   hook.rm( hailhook )
+
+   vn.clear()
+   vn.scene()
+   local p = ccomm.newCharacter( vn, trader )
+   vn.transition()
+   p(fmt.f(_([["Hey, you," the captain of the ship says. "You seem not to know what is going to happen here: a mighty warlord from {sys} is going to attack {pnt}. You shouldn't stay there, unless you are a mercenary. Do you know how it works? If you attack a warlord's ship, and he loses the battle, the other warlord will reward you. But if he wins, you will be hunted down."]]),
+      {sys=source_system, pnt=source_planet}))
+   vn.run()
+
    player.commClose()
 end
 
@@ -134,8 +145,9 @@ local function chooseInList(list)
 end
 
 -- Prepares the reward
+local warrior
 local function prepareReward(massOfVictims)
-   local warrior = chooseInList(side == "attacker" and attackers or defenders)
+   warrior = chooseInList(side == "attacker" and attackers or defenders)
    if warrior == nil then return end -- Simultaneous destruction?
    reward = 20e3 + 60*massOfVictims
    reward = reward * (1 + rnd.sigma() / 3)
@@ -145,8 +157,20 @@ end
 
 function hailagain()
    hook.rm(hailhook)
-   tk.msg(_("Here comes your reward"), fmt.f( _([["Hello captain," a Dvaered officer says, "You helped us in this battle. I am authorized to give you {credits} as a reward."]]), {credits=fmt.credits(reward)}) )
-   player.pay(reward)
+
+   vn.clear()
+   vn.scene()
+   local p = ccomm.newCharacter( vn, warrior )
+   vn.transition()
+   p(fmt.f( _([["Hello captain," a Dvaered officer says, "You helped us in this battle. I am authorized to give you {credits} as a reward."]]),
+      {credits=fmt.credits(reward)}) )
+   vn.func( function ()
+      player.pay(reward)
+   end )
+   vn.sfxMoney()
+   vn.na(fmt.reward(reward))
+   vn.run()
+
    player.commClose()
 end
 
@@ -155,10 +179,12 @@ local function getLeader(list)
    local p = chooseInList(list)
    if p == nil or not p:exists() then
       return nil
-   elseif p:leader() == nil or not p:leader():exists() then
+   end
+   local l = p:leader()
+   if l==nil then
       return p
    else
-      return p:leader()
+      return l
    end
 end
 
