@@ -3,15 +3,30 @@
 <event name="Travelling Merchant">
  <location>enter</location>
  <chance>5</chance>
- <cond>require("common.pirate").systemPresence() &gt; 100 and system.cur():presence("Independent") &gt; 100 and player.credits() &gt;= 1e6 and not system.cur():tags().restricted</cond>
+ <cond>
+   if require("common.pirate").systemPresence() &lt; 100 or system.cur():presence("Independent") &lt; 100 then
+      return false
+   end
+   if system.cur():tags().restricted then
+      return false
+   end
+   if player.credits() &lt; 1e6 and not var.peek("travelling_trader_hailed") then
+      return false
+   end
+   return true
+ </cond>
 </event>
 --]]
 --[[
-
    Travelling Merchant Event
 
 Spawns a travelling merchant that can sell the player if interested.
 
+Player variables:
+* travelling_trader_boarded: player has boarded once the merchant
+* travelling_trader_hailed: misi has been hailed once by the player
+* travelling_trader_hail2: misi has been hailed about new stuff by the player (chapter 1)
+* travelling_trader_data: player has been talked about the new data matrices stuff
 --]]
 local vn = require 'vn'
 local fmt = require "format"
@@ -19,7 +34,8 @@ local love_shaders = require 'love_shaders'
 local der = require "common.derelict"
 local poi = require "common.poi"
 
-local p, broadcastid, hailed_player, second_hail, timerdelay -- Non-persistent state
+local p, broadcastid, hailed_player, second_hail, timerdelay, broadcast_first -- Non-persistent state
+local gen_outfits -- Forward declaration
 
 local trader_name = _("Machiavellian Misi") -- Mireia Sibeko
 local trader_image = "misi.png"
@@ -34,12 +50,12 @@ local broadcastmsg = {
    _("…and that's how I was able to get a third liver haha. Oops is this on? Er, nevermind that. Outfits for sale!"),
 }
 
-
+local misi_outfits
 function create ()
    local scur = system.cur()
 
    -- Inclusive claim
-   if not evt.claim( scur, nil, true ) then evt.finish() end
+   if not naev.claimTest( scur, true ) then evt.finish() end
 
    -- Check to see if a nearby spob is inhabited
    local function nearby_spob( pos )
@@ -93,7 +109,11 @@ function create ()
    p:control()
    p:brake()
 
+   -- Get outfits
+   misi_outfits = gen_outfits()
+
    -- Set up hooks
+   broadcast_first = false
    timerdelay = 10
    broadcastid = 1
    broadcastmsg = rnd.permutation( broadcastmsg )
@@ -111,65 +131,7 @@ function leave ()
     evt.finish()
 end
 
-function broadcast ()
-   -- End the event if for any reason the trader stops existing
-   if not p:exists() then
-      evt.finish()
-      return
-   end
-
-   -- Cycle through broadcasts
-   if broadcastid > #broadcastmsg then broadcastid = 1 end
-   p:broadcast( broadcastmsg[broadcastid], true )
-   broadcastid = broadcastid+1
-   timerdelay = timerdelay * 1.5
-   hook.timer( timerdelay, "broadcast" )
-
-   if not hailed_player and not var.peek('travelling_trader_hailed') then
-      p:hailPlayer()
-      hailed_player = true
-
-   elseif poi.data_get_gained() > 0 and
-         var.peek("travelling_trader_boarded") and
-         not var.peek("travelling_trader_hail2") and
-         not var.peek("travelling_trader_data") then
-      p:hailPlayer()
-      hailed_player = true
-      second_hail = true
-   end
-end
-
-function hail ()
-   if not var.peek('travelling_trader_hailed') then
-      vn.clear()
-      vn.scene()
-      local mm = vn.newCharacter( trader_name,
-         { image=trader_image, color=trader_colour, shader=love_shaders.hologram() } )
-      vn.transition("electric")
-      mm:say( _([["Howdy Human! Er, I mean, Greetings! If you want to take a look at my wonderful, exquisite, propitious, meretricious, effulgent, … wait, what was I talking about? Oh yes, please come see my wares on my ship. You are welcome to board anytime!"]]) )
-      vn.done("electric")
-      vn.run()
-
-      var.push('travelling_trader_hailed', true)
-      player.commClose()
-   elseif second_hail then
-      vn.clear()
-      vn.scene()
-      local mm = vn.newCharacter( trader_name,
-         { image=trader_image, color=trader_colour, shader=love_shaders.hologram() } )
-      vn.transition("electric")
-      mm:say(_([["Howdy Human! I have new propitiuous and meretricious wares available. Come see the wares on my ship!"]]))
-      vn.done("electric")
-      vn.run()
-
-      var.push('travelling_trader_hail2', true)
-      player.commClose()
-
-      second_hail = false
-   end
-end
-
-function board ()
+function gen_outfits ()
    --[[
       Ideas
    * Vampiric weapon that removes shield regen, but regenerates shield by doing damage.
@@ -190,7 +152,7 @@ function board ()
    }
 
    -- Bonus for killing executors
-   if player.numOutfit("Executor Shield Aura")<1 and (var.peek("executors_killed") or 0) >= 3 then
+   if player.outfitNum("Executor Shield Aura")<1 and (var.peek("executors_killed") or 0) >= 3 then
       table.insert( outfits, "Executor Shield Aura" )
    end
 
@@ -209,6 +171,7 @@ function board ()
       { "Operation Cold Metal",     "Left Boot" },
       { "Black Cat",                "Black Cat Doll" },
       { "Terraforming Antlejos 10", "Commemorative Stein" },
+      { "DIY Nerds",                "Homebrew Processing Unit" },
    }
    local event_rewards = {
    }
@@ -219,14 +182,14 @@ function board ()
    for i,r in ipairs(mission_rewards) do
       local m = r[1]
       local o = r[2]
-      if player.misnDone(m) and player.numOutfit(o)<1 then
+      if player.misnDone(m) and player.outfitNum(o)<1 then
          table.insert( outfits, o )
       end
    end
    for i,r in ipairs(event_rewards) do
       local e = r[1]
       local o = r[2]
-      if player.evtDone(e) and player.numOutfit(o)<1 then
+      if player.evtDone(e) and player.outfitNum(o)<1 then
          table.insert( outfits, o )
       end
    end
@@ -240,13 +203,111 @@ function board ()
       for k,v in ipairs(olist) do
          table.insert( outfits, v )
       end
+
+      -- Defeated all the "Goatee" pirates
+      if player.evtDone("Quai Pirates") and player.evtDone("Levo Pirates") and player.evtDone("Capricorn Pirates") and player.evtDone("Surano Pirates") and player.evtDone("Dendria Pirates") then
+         table.insert( outfits, "Goatee Marker" )
+      end
+
+      -- Chapter 1
+      if player.fleetCapacity() > 0 then
+         table.insert( outfits, "Squadron Synchronizer Module" )
+      end
    end
+
+   -- Other special cases
+   local rr = "Rackham's Razor"
+   if player.outfitNum(rr) <= 0 and ((var.peek("poi_red_rackham") or 0)>=3) then
+      table.insert( outfits, rr )
+   end
+
+   return outfits
+end
+
+local newoutfits = false
+function broadcast ()
+   -- End the event if for any reason the trader stops existing
+   if not p:exists() then
+      evt.finish()
+      return
+   end
+
+   -- Check to see if has new outfits
+   for k,o in ipairs(misi_outfits) do
+      if not var.peek("misi_o_"..o) then
+         newoutfits = true
+         break
+      end
+   end
+
+   -- Cycle through broadcasts
+   if broadcastid > #broadcastmsg then broadcastid = 1 end
+
+   if not hailed_player and not var.peek('travelling_trader_hailed') then
+      p:hailPlayer()
+      hailed_player = true
+
+   elseif poi.data_get_gained() > 0 and
+         var.peek("travelling_trader_boarded") and
+         not var.peek("travelling_trader_hail2") and
+         not var.peek("travelling_trader_data") then
+      p:hailPlayer()
+      hailed_player = true
+      second_hail = true
+
+   end
+
+   if not hailed_player and newoutfits and not broadcast_first then
+      -- With new outfits point it out to the player
+      p:comm(_("I have new wares you might want to see!"), true)
+      player.autonavReset(1)
+      broadcast_first = true
+   else
+      p:broadcast( broadcastmsg[broadcastid], true )
+   end
+
+   broadcastid = broadcastid+1
+   timerdelay = timerdelay * 1.5
+   hook.timer( timerdelay, "broadcast" )
+end
+
+function hail ()
+   if not var.peek('travelling_trader_hailed') then
+      vn.clear()
+      vn.scene()
+      local mm = vn.newCharacter( trader_name,
+         { image=trader_image, colour=trader_colour, shader=love_shaders.hologram() } )
+      vn.transition("electric")
+      mm:say( _([["Howdy Human! Er, I mean, Greetings! If you want to take a look at my wonderful, exquisite, propitious, meretricious, effulgent, … wait, what was I talking about? Oh yes, please come see my wares on my ship. You are welcome to board anytime!"]]) )
+      vn.done("electric")
+      vn.run()
+
+      var.push('travelling_trader_hailed', true)
+      player.commClose()
+   elseif second_hail then
+      vn.clear()
+      vn.scene()
+      local mm = vn.newCharacter( trader_name,
+         { image=trader_image, colour=trader_colour, shader=love_shaders.hologram() } )
+      vn.transition("electric")
+      mm:say(_([["Howdy Human! I have new propitiuous and meretricious wares available. Come see the wares on my ship!"]]))
+      vn.done("electric")
+      vn.run()
+
+      var.push('travelling_trader_hail2', true)
+      player.commClose()
+
+      second_hail = false
+   end
+end
+
+function board ()
    -- Boarding sound
    der.sfx.board:play()
 
    vn.clear()
    vn.scene()
-   local mm = vn.newCharacter( trader_name, { image=trader_image, color=trader_colour } )
+   local mm = vn.newCharacter( trader_name, { image=trader_image, colour=trader_colour } )
    vn.transition()
    if not var.peek('travelling_trader_boarded') then
       vn.na(_([[You open the airlock and are immediately greeted by an intense humidity and heat, almost like a jungle. As you advance through the dimly lit ship you can see all types of mold and plants crowing in crevices in the wall. Wait, was that a small animal scurrying around? Eventually you reach the cargo hold that has been re-adapted as a sort of bazaar. As you look around the mess of different wares, most seemingly to be garbage, you suddenly notice a mysterious figure standing infront of you. You're surprised at how you didn't notice them getting so close to you, almost like a ghost.]]))
@@ -290,6 +351,23 @@ They get uncomfortably close
          vn.func( function ()
             var.push("travelling_trader_data",true)
          end )
+      else
+         local sillyphrases = {
+            _("Guaranteed to not smell like they were plundered from some stinky old derelict!"),
+            _("Part of a complete breakfast!"),
+            _("Buy one and get zero free!"),
+            _("Now free of flesh-eating bacteria!"),
+            _("Goes well with a side of rice!"),
+            _("Now with fewer side effects!"),
+         }
+
+         if newoutfits then
+            mm(fmt.f(_([["I haven't seen you in a while old friend! I've gotten some new wares you may want to see. Always the best quality! {sillyphrase}"]]),
+               {sillyphrase = sillyphrases[ rnd.rnd(1,#sillyphrases) ]}))
+         else
+            mm(fmt.f(_([["I haven't seen you in a while old friend! Looking for a bargain again? Always the best quality! {sillyphrase}"]]),
+               {sillyphrase = sillyphrases[ rnd.rnd(1,#sillyphrases) ]}))
+         end
       end
    end
 
@@ -298,9 +376,13 @@ They get uncomfortably close
    vn.label("menu_direct")
    vn.menu( function ()
       local opts = {
-         { _("Shop"), "bazaar" },
          { _("Leave"), "leave" },
       }
+      if newoutfits then
+         table.insert( opts, 1, { _("Shop (#rNew Wares!#0)"), "bazaar" } )
+      else
+         table.insert( opts, 1, { _("Shop"), "bazaar" } )
+      end
       if var.peek("travelling_trader_data") then
          table.insert( opts, 2, { _("Special Services"), "special" } )
       end
@@ -309,7 +391,13 @@ They get uncomfortably close
 
    vn.label("bazaar")
    vn.func( function ()
-      tk.merchantOutfit( store_name, outfits )
+      -- Mark outfits as seen
+      for k,o in ipairs(misi_outfits) do
+         var.push("misi_o_"..o,true)
+      end
+      newoutfits = false
+      -- Open store
+      tk.merchantOutfit( store_name, misi_outfits )
    end )
    vn.jump("menu")
 
@@ -355,10 +443,14 @@ They get uncomfortably close
             end
          end
       end )
-      mm(fmt.f(_([["I would be able to provide my special services for, let's say, {cost}, how does that sound?"
+      mm( function ()
+         return fmt.f(_([["I would be able to provide my special services for, let's say, {cost}, how does that sound?"
+
+{upgrade_desc}
 
 You have {amount}. Pay {cost} for {upgrade}?]]),
-         {amount=poi.data_str(poi.data_get()), cost=poi.data_str(upgrade_cost), upgrade=upgrade} ))
+            {amount=poi.data_str(poi.data_get()), cost=poi.data_str(upgrade_cost), upgrade=upgrade, upgrade_desc=upgrade:summary()} )
+      end )
       vn.menu{
          { _("Pay"), s.."_yes" },
          { _("Back"), s.."_no" },
@@ -375,8 +467,10 @@ You have {amount}. Pay {cost} for {upgrade}?]]),
       mm( function ()
          return fmt.f(_([["It seems like I have already upgraded your current ship with {replacement}. Would you like to replace it with {upgrade} for 2 Encrypted Data Matrices?"
 
+{upgrade_desc}
+
 You have {amount}. Pay {cost} for replacing {replacement} with {upgrade}?]]),
-            {amount=poi.data_str(poi.data_get()), cost=poi.data_str(upgrade_cost), upgrade=upgrade, replacement=replacement} )
+            {amount=poi.data_str(poi.data_get()), cost=poi.data_str(upgrade_cost), upgrade=upgrade, replacement=replacement, upgrade_desc=upgrade:summary()} )
       end )
       vn.menu{
          { _("Pay"), s.."_yes" },
@@ -391,7 +485,7 @@ You have {amount}. Pay {cost} for replacing {replacement} with {upgrade}?]]),
          end
       end )
       mm(_([["This will take a second."
-They grab a toolbox and rush over to your boarded ship. You decide not to follow as somethings are best left not known. At least they know what they are doing right?]]))
+They grab a toolbox and rush over to your boarded ship. You decide not to follow as some things are best left not known. At least they know what they are doing right?]]))
       mm(_([[Eventually, they come back covered in what seems to be fish parts and slime.
 "That was fun! However, when I put it back together, I found some extra screws. Oh well, it does seem to hold together fairly well. Hope you enjoy the upgrades! The fish smell will go away in a few periods hopefully."]]))
       vn.func( function ()
@@ -422,6 +516,9 @@ They grab a toolbox and rush over to your boarded ship. You decide not to follow
    mm(_([["Machiavellian Necessity focuses on tweaking your weapon systems to be able to take decisive action when necessary."
 "Machiavellian Fortune will help you minimize the risks of fickleness of fortune."
 "Finally, Machiavellian Virtue will make you a bulwark against unforeseen mishaps."]]))
+   for k,v in pairs(upgrade_list) do
+      mm(v:summary())
+   end
    vn.jump("special")
 
    vn.label("leave")
