@@ -14,6 +14,7 @@ local gauntlet_gui = require 'missions.dvaered.gauntlet.gui'
 local tables = require 'missions.dvaered.gauntlet.tables'
 local fmt = require "format"
 local equipopt = require 'equipopt'
+local flow = require "ships.lua.lib.flow"
 
 local logidstr = "log_gauntlet"
 local enemies, enemy_faction, gmods, wave_enemies, wave_killed -- Non-persistent state
@@ -97,7 +98,7 @@ function abort ()
 end
 
 -- Clears pilots include the player's escorts
-local function clear_pilots ()
+function clear_pilots ()
    gauntlet.clear_pilots()
 end
 
@@ -238,6 +239,7 @@ function wave_round_setup ()
    end
    pp:fillAmmo() -- Have to fill ammo or deployed fighters get "lost"
    -- TODO reset outfit cooldown stuff
+   flow.reset( pp )
    pp:setPos( vec2.new( 0, 0 ) ) -- teleport to middle
    pp:setVel( vec2.new( 0, 0 ) )
 
@@ -436,6 +438,7 @@ function wave_end ()
       local s = 1.2 -- time to display each message
       local f = (n+2)*s
       player.omsgAdd( string.format( "#p".._("WAVE %d CLEAR").."#0", mem.wave_round ), f )
+      hook.safe( "clear_pilots" ) -- can't be done in the same frame as it is run on an enemy hook
       sfx_clear:play()
       for k,v in pairs(score_str) do
          local start = k*s
