@@ -322,7 +322,7 @@ function approach_malik ()
 #rHUMAN LIFE SAFETY OVERRIDE.
 DUEL TO THE DEATH MODE ENABLED.#0]]))
    vn.sfxEerie()
-   vn.na(_([[You try to remove the gear, but it's too late. The virtual reality of the Crimson Gauntlet envelopes you…]]))
+   vn.na(_([[You try to remove the gear, but it's too late. The virtual reality of the Crimson Gauntlet envelops you…]]))
    vn.done()
 
    vn.label("decline")
