@@ -18,6 +18,7 @@ local sdf         = require "vn.sdf"
 local opt         = require "vn.options"
 local luaspfx     = require "luaspfx"
 local luatk       = require "luatk"
+local fmt         = require "format"
 
 local vn = {
    speed = var.peek("vn_textspeed") or 0.025,
@@ -76,6 +77,7 @@ local function _setdefaults()
    vn._default.menu_y = nil
    vn._default._postshader = nil
    vn._default._draw_fg = nil
+   vn._default._draw_mg = nil
    vn._default._draw_bg = nil
    vn._default._updatefunc = nil
    -- Options
@@ -120,19 +122,19 @@ Sets the current drawing colour of the VN.
    @tparam tab col Colour table consisting of 3 or 4 number values.
    @tparam[opt=1] number alpha Additional alpha to multiply by.
 --]]
-function vn.setColor( col, alpha )
+function vn.setColour( col, alpha )
    local a = col[4] or 1
    alpha = alpha or 1
    a = a*alpha
-   graphics.setColor( col[1], col[2], col[3], a*vn._globalalpha )
+   graphics.setColour( col[1], col[2], col[3], a*vn._globalalpha )
 end
 
 local function _draw_bg( x, y, w, h, col, border_col, alpha )
    col = col or {0, 0, 0, 1}
    border_col = border_col or {0.5, 0.5, 0.5, 1}
-   vn.setColor( border_col, alpha )
+   vn.setColour( border_col, alpha )
    graphics.rectangle( "fill", x, y, w, h )
-   vn.setColor( col, alpha )
+   vn.setColour( col, alpha )
    graphics.rectangle( "fill", x+2, y+2, w-4, h-4 )
 end
 
@@ -181,7 +183,7 @@ local function _draw_character( c )
    if c.shader and c.shader.prerender then
       c.shader:prerender( c.image )
    end
-   vn.setColor( col, c.alpha )
+   vn.setColour( col, c.alpha )
    graphics.setShader( c.shader )
    graphics.draw( c.image, x, y, r, flip*scale, scale )
    graphics.setShader()
@@ -226,8 +228,13 @@ local function _draw()
    local bh = 20
    _draw_bg( x, y, w, h, vn.textbox_bg, nil, vn.textbox_bg_alpha )
    -- Draw text
-   vn.setColor( vn._bufcol, vn.textbox_text_alpha )
-   graphics.setScissor( x, y+bh, w, h-2*bh )
+   vn.setColour( vn._bufcol, vn.textbox_text_alpha )
+   -- We pad a bit here so that the top doesn't get cut off from certain
+   -- characters that extend above the font height
+   local padh = font:getLineHeight()-font:getHeight()
+   graphics.setScissor( x, y+bh-padh, w, h-2*bh+padh )
+   -- We're actually printing the entire text and using scissors to cut it out
+   -- TODO only show the visible text while not trying to render it
    y = y + vn._buffer_y
    graphics.printf( vn._buffer, font, x+bw, y+bh, w-3*bw )
    graphics.setScissor()
@@ -246,10 +253,15 @@ local function _draw()
       end
       _draw_bg( x, y, w, h, vn.namebox_bg, nil, vn.namebox_alpha )
       -- Draw text
-      vn.setColor( vn._bufcol, vn.namebox_alpha )
+      vn.setColour( vn._bufcol, vn.namebox_alpha )
       graphics.print( vn._title, font, x+bw, y+bh )
    end
 
+   -- Custom Namebox
+   if vn._draw_mg then
+      vn._draw_mg()
+   end
+
    -- Options
    if vn.show_options then
       x = vn.options_x
@@ -264,12 +276,12 @@ local function _draw()
       end
       _draw_bg( x, y, w, h, colbg, nil, 1 )
       graphics.setShader( sdf.gear )
-      vn.setColor( {0.95,0.95,0.95} )
+      vn.setColour( {0.95,0.95,0.95} )
       sdf.img:draw( x+5, y+5, 0, w-10, h-10 )
       graphics.setShader()
    end
 
-   -- Draw if necessary
+   -- Draw current state if necessary
    if not vn.isDone() then
       local s = vn._states[ vn._state ]
       s:draw()
@@ -284,7 +296,7 @@ local function _draw()
       -- Draw canvas
       graphics.setCanvas( prevcanvas )
       graphics.setShader( vn._postshader )
-      vn.setColor( {1, 1, 1, 1} )
+      vn.setColour( {1, 1, 1, 1} )
       graphics.setBlendMode( "alpha", "premultiplied" )
       vn._canvas:draw( 0, 0 )
       graphics.setBlendMode( "alpha" )
@@ -375,8 +387,14 @@ end
 --[[--
 Key press handler.
    @tparam string key Name of the key pressed.
+   @tparam boolean isrepeat Whether or not the string is repeating.
 --]]
-function vn.keypressed( key )
+function vn.keypressed( key, isrepeat )
+   if love._vn_keyrepeat_check and isrepeat then
+      return false
+   end
+   love._vn_keyrepeat_check = false
+
    local tkopen = luatk.isOpen()
    if not tkopen and string.lower(naev.keyGet( "menu" )) == key then
       naev.menuSmall()
@@ -493,6 +511,15 @@ function vn.mousereleased( mx, my, button )
    return s:mousereleased( mx, my, button )
 end
 
+--[[--
+Mouse wheel handler.
+--]]
+function vn.wheelmoved( dx, dy )
+   if vn.isDone() then return false end
+   local s = vn._states[ vn._state ]
+   return s:wheelmoved( dx, dy )
+end
+
 --[[--
 Text input handler.
 --]]
@@ -537,6 +564,7 @@ function vn.State.new()
    s._mousepressed = _dummy
    s._mousereleased = _dummy
    s._mousemoved = _dummy
+   s._wheelmoved = _dummy
    s._keypressed = _dummy
    s._textinput = _dummy
    s.done = false
@@ -570,6 +598,11 @@ function vn.State:mousemoved( mx, my, dx, dy )
    vn._checkDone()
    return ret
 end
+function vn.State:wheelmoved( dx, dy )
+   local ret = self:_wheelmoved( dx, dy )
+   vn._checkDone()
+   return ret
+end
 function vn.State:keypressed( key )
    local ret = self:_keypressed( key )
    vn._checkDone()
@@ -581,6 +614,7 @@ function vn.State:textinput( key )
    return ret
 end
 function vn.State:isDone() return self.done end
+local __needs_transition
 --[[
 -- Scene
 --]]
@@ -592,6 +626,8 @@ function vn.StateScene.new()
    return s
 end
 function vn.StateScene:_init()
+   __needs_transition = true
+
    -- Render previous scene to an image
    local canvas = vn._prevcanvas
    _draw_to_canvas( canvas )
@@ -608,6 +644,8 @@ function vn.StateScene:_init()
 
    -- Clear stuff
    vn._buffer = ""
+   vn._buffer_y = 0
+   vn._title = nil
 
    _finish(self)
 end
@@ -623,6 +661,23 @@ function vn.StateCharacter.new( character, remove )
    s.remove = remove or false
    return s
 end
+local function _getpos( pos )
+   pos = pos or "center"
+   if type(pos)=="number" then
+      return pos
+   elseif pos == "center" then
+      return 0.5
+   elseif pos == "left" then
+      return 0.25
+   elseif pos == "right" then
+      return 0.75
+   elseif pos == "farleft" then
+      return 0.15
+   elseif pos == "farright" then
+      return 0.85
+   end
+   return 0.5
+end
 function vn.StateCharacter:_init()
    if self.remove then
       local found = false
@@ -641,20 +696,7 @@ function vn.StateCharacter:_init()
       table.insert( vn._characters, c )
       c.alpha = 1
       c.displayname = c.who -- reset name
-      local pos = self.character.pos or "center"
-      if type(pos)=="number" then
-         self.character.offset = pos
-      elseif pos == "center" then
-         self.character.offset = 0.5
-      elseif pos == "left" then
-         self.character.offset = 0.25
-      elseif pos == "right" then
-         self.character.offset = 0.75
-      elseif pos == "farleft" then
-         self.character.offset = 0.15
-      elseif pos == "farright" then
-         self.character.offset = 0.85
-      end
+      self.character.offset = _getpos( self.character.pos )
    end
    _finish(self)
 end
@@ -675,6 +717,10 @@ function vn.StateSay.new( who, what, noclear )
    return s
 end
 function vn.StateSay:_init()
+   if __needs_transition then
+      warn(_("vn: vn.say being used after vn.scene without a vn.transition!"))
+   end
+
    -- Get the main text
    if type(self._what)=="function" then
       self.what = self._what()
@@ -701,7 +747,7 @@ function vn.StateSay:_init()
    end
    self._len = utf8.len( self._textbuf )
    local c = vn._getCharacter( self.who )
-   vn._bufcol = c.color or vn._default._bufcol
+   vn._bufcol = c.colour or vn._default._bufcol
    if c.hidetitle then
       vn._title = nil
    else
@@ -755,7 +801,7 @@ function vn.StateSay:_finish()
    log.add{
       who   = c.displayname or c.who,
       what  = self.what, -- Avoids newlines
-      colour= c.color or vn._default._bufcol,
+      colour= c.colour or vn._default._bufcol,
    }
 
    _finish( self )
@@ -769,6 +815,7 @@ function vn.StateWait.new()
    s._init = vn.StateWait._init
    s._draw = vn.StateWait._draw
    s._mousepressed = vn.StateWait._mousepressed
+   s._wheelmoved = vn.StateWait._wheelmoved
    s._keypressed = vn.StateWait._keypressed
    s._type = "Wait"
    return s
@@ -795,8 +842,8 @@ function vn.StateWait:_init()
    self._scrolled = _check_scroll( self._lines )
 end
 function vn.StateWait:_draw()
-   --vn.setColor( vn._bufcol )
-   vn.setColor( {0,1,1,1} )
+   --vn.setColour( vn._bufcol )
+   vn.setColour( {0,1,1,1} )
    if vn._buffer_y < 0 then
       graphics.setShader( sdf.arrow )
       graphics.draw( sdf.img, self._x-10, vn.textbox_y+30, -math.pi/2, 45, 15  )
@@ -822,14 +869,46 @@ end
 function vn.StateWait:_mousepressed( _mx, _my, _button )
    wait_scrollorfinish( self )
 end
+function vn.StateWait:_wheelmoved( _dx, dy )
+   if dy > 0 then -- upwards movement
+      vn._buffer_y = vn._buffer_y + vn.textbox_font:getLineHeight()
+      vn._buffer_y = math.min( 0, vn._buffer_y )
+      self._scrolled = _check_scroll( self._lines )
+      return true
+   elseif dy < 0 then -- downwards movement
+      vn._buffer_y = vn._buffer_y - vn.textbox_font:getLineHeight()
+      vn._buffer_y = math.max( vn._buffer_y, (vn.textbox_h - 40) - vn.textbox_font:getLineHeight() * (#self._lines) )
+      self._scrolled = _check_scroll( self._lines )
+      -- we don't check for finish, have to click for that
+      return true
+   end
+   return false
+end
 function vn.StateWait:_keypressed( key )
-   if key=="up" or key=="pageup" then
+   if key=="up" then
       if vn._buffer_y < 0 then
          vn._buffer_y = vn._buffer_y + vn.textbox_font:getLineHeight()
       end
+      vn._buffer_y = math.min( 0, vn._buffer_y )
+      self._scrolled = _check_scroll( self._lines )
+      return true
+   elseif key=="pageup" then
+      if vn._buffer_y < 0 then
+         local fonth = vn.textbox_font:getLineHeight()
+         local h = (math.floor( vn.textbox_h / fonth )-1) * fonth
+         vn._buffer_y = math.min( 0, vn._buffer_y+h )
+      end
+      self._scrolled = _check_scroll( self._lines )
+      return true
+   elseif key=="pagedown" then
+      local fonth = vn.textbox_font:getLineHeight()
+      local h = (math.floor( vn.textbox_h / fonth )-2) * fonth -- wait_scrollorfinish adds an extra line movement
+      vn._buffer_y = math.max( vn._buffer_y-h, (vn.textbox_h - 40) - vn.textbox_font:getLineHeight() * (#self._lines) )
+      wait_scrollorfinish( self )
       return true
    elseif key=="home" then
       vn._buffer_y = 0
+      self._scrolled = _check_scroll( self._lines )
       return true
    elseif key=="end" then
       vn._buffer_y = (vn.textbox_h - 40) - vn.textbox_font:getLineHeight() * (#self._lines)
@@ -842,7 +921,6 @@ function vn.StateWait:_keypressed( key )
       "space",
       "right",
       "down",
-      "pagedown",
       "escape",
    }
    local found = false
@@ -884,8 +962,8 @@ function vn.StateMenu:_init()
       self._items = self.items
    end
    if __debugging then
-      if self._items == nil then
-         warn(_("[VN]: menu has no options!"))
+      if self._items == nil or #self._items==0 then
+         error(_("vn: menu has no options!"))
       end
    end
    -- Set up the graphics stuff
@@ -896,12 +974,14 @@ function vn.StateMenu:_init()
    self._tb = tb
    self._b = b
    -- Get longest line
+   local wmin = 300
+   local wmax = 900
    local w = 0
    local h = 0
    self._elem = {}
    for k,v in ipairs(self._items) do
       local text = string.format("#w%d#0. %s", k, v[1])
-      local sw, wrapped = font:getWrap( text, 900 )
+      local sw, wrapped = font:getWrap( text, wmax )
       sw = sw + 2*tb
       local sh =  2*tb + font:getHeight() + font:getLineHeight() * (#wrapped-1)
       local elem = { text, 0, h, sw, sh }
@@ -911,7 +991,7 @@ function vn.StateMenu:_init()
       h = h + sh + b
       self._elem[k] = elem
    end
-   self._w = math.max( w, 300 )
+   self._w = math.max( w, wmin ) -- enforce minimum size
    self._h = h-b
    self._x = (love.w-self._w)/2
    self._y = (love.h-self._h)/2-100
@@ -950,10 +1030,10 @@ function vn.StateMenu:_draw()
       else
          col = {0.2, 0.2, 0.2}
       end
-      vn.setColor( col )
+      vn.setColour( col )
       graphics.rectangle( "fill", gx+x, gy+y, w, h )
-      vn.setColor( {0.7, 0.7, 0.7} )
-      graphics.print( text, font, gx+x+tb, gy+y+tb )
+      vn.setColour( {0.7, 0.7, 0.7} )
+      graphics.printf( text, font, gx+x+tb, gy+y+tb, w-tb*2 )
    end
 end
 function vn.StateMenu:_mousepressed( mx, my, button )
@@ -966,7 +1046,7 @@ function vn.StateMenu:_mousepressed( mx, my, button )
       local _text, x, y, w, h = table.unpack(v)
       if _inbox( mx, my, gx+x-b, gy+y-b, w+2*b, h+2*b ) then
          self:_choose(k)
-         return
+         return true
       end
    end
 end
@@ -976,6 +1056,7 @@ function vn.StateMenu:_keypressed( key )
    if n==0 then n = n + 10 end
    if n > #self._items then return false end
    self:_choose(n)
+   return true
 end
 function vn.StateMenu:_choose( n )
    vn._sfx.ui.option:play()
@@ -1169,7 +1250,7 @@ function vn.Character.new( who, params )
    setmetatable( c, vn.Character_mt )
    params = params or {}
    c.who = who
-   c.color = params.color or vn._default.color
+   c.colour = params.colour or vn._default.colour
    local pimage = params.image
    if pimage ~= nil then
       local img
@@ -1192,7 +1273,7 @@ function vn.Character.new( who, params )
          end
          local iw, ih = img:getDimensions()
          if iw <= 256 or ih <= 256 then
-            img:setFilter("nearest")
+            img:setFilter( "linear", "nearest" )
          end
       elseif pimage._type=="ImageData" then
          img = graphics.newImage( pimage )
@@ -1255,7 +1336,7 @@ local function _appear_setup( c, shader )
 
             local oldshader = graphics.getShader()
             graphics.setShader( shader )
-            vn.setColor( {1, 1, 1, 1} )
+            vn.setColour( {1, 1, 1, 1} )
             graphics.setBlendMode( "alpha", "premultiplied" )
             vn._curcanvas:draw( 0, 0 )
             graphics.setBlendMode( "alpha" )
@@ -1278,7 +1359,7 @@ end
 Makes a character appear in the VN.
    @see vn.transition
    @see vn.appear
-   @tparam Character c Character to make appear.
+   @tparam Character|table c Character or table of Characters to make appear.
    @tparam[opt="fade"] string name Name of the transition effect to use (see vn.transition)
    @tparam number seconds Seconds to do the transition.
    @tparam[opt="linear"] string transition Name of the CSS transition to use.
@@ -1338,6 +1419,25 @@ function vn.disappear( c, name, seconds, transition )
    end
 end
 
+--[[--
+Moves a character to another position.
+
+   @see vn.animation
+   @tparam Character c Character to move.
+   @tparam[opt="center"] string|number pos Position to move to. Can be either a [0,1] value, "center", "left", "right", "farleft", or "farright".
+--]]
+function vn.move( c, pos )
+   local function runinit ()
+      local cpos = c.offset
+      local tpos = _getpos( pos )
+      return { cpos, tpos }
+   end
+   vn.animation( 1, function( alpha, _dt, params )
+      local cpos, tpos = table.unpack(params)
+      c.offset = tpos*alpha + cpos*(1-alpha)
+   end, nil, "ease-in-out", runinit )
+end
+
 --[[--
 Starts a new scene.
 --]]
@@ -1358,9 +1458,14 @@ Has a character say something.
 ]]
 function vn.say( who, what, noclear, nowait )
    vn._checkstarted()
-   table.insert( vn._states, vn.StateSay.new( who, what, noclear ) )
-   if not nowait then
-      table.insert( vn._states, vn.StateWait.new() )
+   if type(what)~="table" then
+      what = {what}
+   end
+   for k,s in ipairs(what) do
+      table.insert( vn._states, vn.StateSay.new( who, s, noclear ) )
+      if not nowait then
+         table.insert( vn._states, vn.StateWait.new() )
+      end
    end
 end
 
@@ -1435,19 +1540,43 @@ Stops certain playing music.
 --]]
 function vn.musicStop( filename )
    vn.func( function ()
-      lmusic.stop( filename )
+      if type(filename)=="table" and filename.m then
+         lmusic.stop( filename.m )
+      else
+         lmusic.stop( filename )
+      end
    end )
 end
 
 --[[--
 Sets the pitch for playing music.
 
-   @tparam string|nil filename Name of the music to change pitch of or all if nil.
+   @tparam table|string|nil data Name of the music to change pitch of or all if nil. Passing the table returned from vn.music can also be done to specify the music.
    @tparam number p Pitch to set.
 --]]
-function vn.musicPitch( filename, p )
+function vn.musicPitch( data, p )
    vn.func( function ()
-      lmusic.setPitch( filename, p )
+      if type(data)=="table" and data.m then
+         lmusic.setPitch( data.m, p )
+      else
+         lmusic.setPitch( data, p )
+      end
+   end )
+end
+
+--[[--
+Sets the volume for playing music.
+
+   @tparam table|string|nil data Name of the music to change volume of or all if nil. Passing the table returned from vn.music can also be done to specify the music.
+   @tparam number p Volume to set.
+--]]
+function vn.musicVolume( data, p )
+   vn.func( function ()
+      if type(data)=="table" and data.m then
+         lmusic.setVolume( data.m, p )
+      else
+         lmusic.setVolume( data, p )
+      end
    end )
 end
 
@@ -1462,6 +1591,7 @@ function vn.done( ... )
    vn.func( function ()
       vn._globalalpha = 0
       vn._draw_fg = nil
+      vn._draw_mg = nil
       vn._draw_bg = nil
       vn._postshader = nil
       vn._update = nil
@@ -1510,6 +1640,7 @@ function vn.transition( name, seconds, transition )
          end
       end, nil, -- no draw function
       transition, function () -- init
+         __needs_transition = false
          shader:send( "texprev", vn._prevscene )
          if shader:hasUniform( "u_r" ) then
             shader:send( "u_r", love_math.random() )
@@ -1626,6 +1757,15 @@ function vn.setForeground( drawfunc )
    vn._draw_fg = drawfunc
 end
 
+--[[--
+Sets the middle drawing function. Drawn in right in front of the normal "namebox".
+
+   @tparam func drawfunc Function to call to draw the middle or nil to disable.
+--]]
+function vn.setMiddle( drawfunc )
+   vn._draw_mg = drawfunc
+end
+
 --[[--
 Sets a custom update function. This gets run every frame.
 
@@ -1691,7 +1831,43 @@ function vn.run()
    if #vn._states == 0 then
       error( _("vn: run without any states") )
    end
+   -- Check for duplicate labels
+   if __debugging then
+      local jumps = {}
+      local labels = {}
+      local menu_jumps = {}
+      for k,s in ipairs( vn._states ) do
+         if s._type=="Label" then
+            table.insert( labels, s.label )
+         elseif s._type=="Jump" then
+            table.insert( jumps, s.label )
+         elseif s._type=="Menu" then
+            if type(s.items)=="table" then
+               for i,m in ipairs(s.items) do
+                  table.insert( menu_jumps, m[2] )
+               end
+            end
+         end
+      end
+      table.sort( labels )
+      for k,v in ipairs(labels) do
+         if v==labels[k+1] then
+            warn(fmt.f(_("vn: Duplicate label '{lbl}'!"),{lbl=v}))
+         end
+      end
+      for k,v in ipairs(jumps) do
+         if not inlist( labels, v ) then
+            warn(fmt.f(_("vn: Jump to non-existent label '{lbl}'!"),{lbl=v}))
+         end
+      end
+      for k,v in ipairs(menu_jumps) do
+         if not inlist( labels, v ) then
+            warn(fmt.f(_("vn: Manu has jump to non-existent label '{lbl}'!"),{lbl=v}))
+         end
+      end
+   end
    love._vn = true
+   love._vn_keyrepeat_check = true
    love.exec( 'scripts/vn' )
    love._vn = nil
    vn._started = false
@@ -1704,7 +1880,7 @@ end
 --[[--
 Clears the fundamental running variables. Run before starting a new VN instance.
 
-<em>Note</em> Leaves customization to colors and positions untouched.
+<em>Note</em> Leaves customization to colours and positions untouched.
 --]]
 function vn.clear()
    local var = {
@@ -1741,8 +1917,8 @@ function vn.reset()
 end
 
 -- Default characters
-vn._me = vn.Character.new( "You", { color={1, 1, 1}, hidetitle=true } )
-vn._na = vn.Character.new( "Narrator", { color={0.5, 0.5, 0.5}, hidetitle=true } )
+vn._me = vn.Character.new( "You", { colour={1, 1, 1}, hidetitle=true } )
+vn._na = vn.Character.new( "Narrator", { colour={0.5, 0.5, 0.5}, hidetitle=true } )
 
 -- Set defaults
 _setdefaults()
